@@ -6,6 +6,7 @@ module Test.Framework.Improving (
 
 import Control.Concurrent
 import Control.Monad
+import Control.Applicative
 
 import System.Timeout
 
@@ -35,6 +36,10 @@ newtype ImprovingIO i f a = IIO { unIIO :: Chan (Either i f) -> IO a }
 instance Functor (ImprovingIO i f) where
     fmap = liftM
 
+instance Applicative (ImprovingIO i f) where
+    pure  = return
+    (<*>) = ap
+
 instance Monad (ImprovingIO i f) where
     return x = IIO (const $ return x)
     ma >>= f = IIO $ \chan -> do
@@ -79,4 +84,4 @@ timeoutImprovingIO microseconds iio = IIO $ \chan -> timeout microseconds $ unII
 -- as the number of microseconds to apply the time out for.
 maybeTimeoutImprovingIO :: Maybe Int -> ImprovingIO i f a -> ImprovingIO i f (Maybe a)
 maybeTimeoutImprovingIO Nothing             = fmap Just
-maybeTimeoutImprovingIO (Just microseconds) = timeoutImprovingIO microseconds
\ No newline at end of file
+maybeTimeoutImprovingIO (Just microseconds) = timeoutImprovingIO microseconds
